@@ -325,8 +325,10 @@ def watch(kubeconfig: str, config: str, param: list[str], cluster: str, namespac
 
 
 def run_command(cmd: Command, kubeconfig: str, config: str, params: list[str], cluster:str, namespace: str, pod: str, extra_args):
-    KubeContext.init_config(kubeconfig)
-    if not KubeContext.init_params(config, params):
+    is_user_entry = cmd.command() == UserEntry().command()
+
+    KubeContext.init_config(kubeconfig, is_user_entry=is_user_entry)
+    if not KubeContext.init_params(config, params, is_user_entry=is_user_entry):
         return
 
     state = ReplState(ns_sts=cluster, pod=pod, namespace=namespace)
