@@ -29,7 +29,7 @@ class TearDownFrontend(Command):
         if not self.validate_state(state):
             return state
 
-        name = 'kaqing'
+        name = 'ops'
         Ingresses.delete_ingress(name, state.namespace)
         Services.delete_service(name, state.namespace)
 
